
####FOR FULL REPLICATION PLEASE DOWNLOAD "web.stable_lights.avg_vis.tif" FILES FOR ALL SATELLITE-YEARS OF AVAILABLE DMSP-OLS DATA###
####THE MAPS ARE AVAILABLE HERE: https://ngdc.noaa.gov/eog/dmsp/downloadV4composites.html####
####RADIANCE CALIBRATED MAPS AVAILABLE HERE: https://ngdc.noaa.gov/eog/dmsp/download_radcal.html####
####ONCE DOWNLOADED PLEASE CHANGE FILE NAMES TO REFLECT PLACEMENT OF THESE FILES AS WELL AS REPLICATION FOLDER####
####IF NIGHTTIME LIGHTS AND REPLICATION FOLDER ARE IN THE SAME FOLDER IN COMPUTER, USE Ctrl+R TO REPLACE "~" WITH HOSTING DIRECTORY######


####NOTE: THE CODE HERE WILL REPLICATE EVERY PART OF THE ARTICLE AND APPENDIX *EXCEPT* TABLE 2 IN THE ARTICLE AND TABLE S8 IN THE APPENDIX
####WHICH ARE REPLICATED WITH THE STATA .DTA AND .DO FILE

####Libraries####

setwd("~")
summremove.packages("Rcpp")
install.packages("Rcpp")
install.packages('TMB', type = 'source')
library(sjPlot)
library(stargazer)
library(car)
library(multiwayvcov)
library(xtable)
library(lmtest)
library(ggplot2)
library(maptools)
library(sp)
library(ggspatial)
library(raster)
library(rgdal)
library(tmaptools)
library(tmap)
library(sp)
library(mapview)
library(dplyr)
library(stargazer)
library(spatialEco)
library(devtools)
library(maps)  

#####Load De Juan and Bank (2015) Replication Data####

###The updated_full file will need to be compiled in the order of the code###
xx <-read.csv("xx_updated_full.csv")
###The _complete file is fully compiled and can be used to run any regression without running other code beforehand###
xx<-read.csv("xx_complete.csv")

####CODEBOOK for xx_complete####
#l3_pcode - sub-distrcit (L3) code
#gov_en - Governorate (L1) name
#nahya_id - subdistrict (L3) code without "SYR" prefix
#gov_id - Governorate (L1) code
#pop_2004 - Population count from 2004 census
#totaldeath - Count of nahiya deaths from Syria Tracker through November 2014
#lenthkm - longest distance between two points in nahiya in kilometers
#areaqkm - nahiya area in square km
#sunni - are there Sunnis in the nahiya (Izady 2000)
#alawites - are there alawis in the nahiya (Izady 2000)
#sc_malunempl - Census 2004: unemployment rate in nahiya
#sc_enrollement - Census 2004: school enrollment in 6-11th grades
#sc_emplgov - Census 2004: percentage employed by the government in nahiya
#sc_electricity - Census 2004: percentage of households in nahiya with access to electricity
#sc_ownedhouse - census 2004: percentage of households that owned their house in nahiya
#border_dist - average distance to border with another country
#gov_cap_hub_name - Name of governorate (L1) capital
#gov_capital_dist - nahiya distance from governorate capital
#neigh_totaldeath - Total deaths in neighboring nawahi (Syria Tracker)
#sc_industrial_workers - Census 2004: Percent industrial workers in nahiya
#gdelt5 - Deaths in nahiya from GDELT data
#dist_all_powerstations - Distance to nearest power stations
#epr_alawi_dum - Alawis in nahiya based on Ethnic Power relations data
#epr_kurd_sunni_dum - Sunni Kurds in nahiya based on Ethnic Power relations data
#epr_arab_sunni_dum - Sunni Arabs in nahiya based on Ethnic Power relations data
#dum_pos_ligmean_change_0908 - Position nighttime light change from 2008 to 2009 (both F16 satellites)
#ligmean_change_0907 - Differences in the mean nighttime light intensity from 2007 to 2009 (both F16 satellites)
#rate_ligmean_change_0907 - Percent change in nighttime light mean difference from 2007 to 2009
#share_urban_2004 - Percent of nahiya covered by urban areas
#dum_fat_total_25 - Dummy variable of whether there were more than 25 total deaths in a nahiya from Syria Tracker
#dum_fat_total_5 - Dummy variable of whether there were more than 5 total deaths in a nahiya from Syria Tracker
#dum_fat_total_10 - Dummy variable of whether there were more than 10 total deaths in a nahiya from Syria Tracker
#dum_fat_total_20 - Dummy variable of whether there were more than 20 total deaths in a nahiya from Syria Tracker
#dum_fat_total_50 - Dummy variable of whether there were more than 50 total deaths in a nahiya from Syria Tracker
#dum_fat_mar_feb_25 - Dummy variable of whether there were more than 25 total deaths in a nahiya from Syria Tracker through February 2012
#dum_gov_capital - Dummy variable if nahiya is the governorate capital
#dum_gov_oilgas - Dummy variable if the governorate (L1) contains centers of oil and gas production
#log_dist_powerstation - Log of the distance from a power station of a given nahiya
#log_pop_2004 - Log of nahiya population (2004 Census)
#road_density - Average road density in nahiya
#log_border_dist - Log average border distance in nahiya
#nahya_en- Nahiya name in English
#z04mean - Mean 2004 nighttime light intensity in nahiya
#z05mean - Mean 2005 nighttime light intensity in nahiya
#z06mean - Mean 2006 nighttime light intensity in nahiya
#z07mean - Mean 2007 nighttime light intensity in nahiya
#z08mean - Mean 2008 nighttime light intensity in nahiya
#z09mean - Mean 2009 nighttime light intensity in nahiya
#d0904 - Mean difference from 2004 to 2009 nighttime light intensity in nahiya
#d0905 - Mean difference from 2005 to 2009 nighttime light intensity in nahiya
#d0906 - Mean difference from 2006 to 2009 nighttime light intensity in nahiya
#d0907 - Mean difference from 2007 to 2009 nighttime light intensity in nahiya
#d0908 - Mean difference from 2008 to 2009 nighttime light intensity in nahiya
#d0704 - Mean difference from 2004 to 2007 nighttime light intensity in nahiya
#d0804 - Mean difference from 2004 to 2008 nighttime light intensity in nahiya
#g1 - g13 - governorate dummies
#sh_ - any variable with sh prefix is the Syrian shuhada data appended by study authors and not used in the study
#nosat0907 - Difference betweeen 2007 and 2009 without saturated pixels (DN>59)
#noflares0907 - Difference between 2007 and 2009 without 10km buffers containing gas flares
#nosat1006 - DIfference between radiance calibrated images from 2006 and 2010
#nosatnoflares1006 - DIfference between radiance calibrated images from 2006 and 2010 also excluding gas flare buffers
#lnosat1006 - Log difference between radiance calibrated images from 2006 and 2010
#lnosatnoflares1006 - Log difference between radiance calibrated images from 2006 and 2010 also excluding gas flare buffers
#orig0907.shift - Difference between 2007 and 2009 composites correcting for signal shift
#nosat0907.shift -Difference between 2007 and 2009 composites correcting for signal shift without saturated pixels (DN>59)
#noflares0907.shift - Difference between 2007 and 2009 composites correcting for signal shift without 10km buffers around gas flares
#nosatnoflares0907.shift - Difference between 2007 and 2009 composites correcting for signal shift without saturated pixels and gas flares


##########Shifting 2009  nightlights########
###Shifting the rasters from 2009
nightlights2007 <- raster('~/F162007.v4/F162007.v4b_web.stable_lights.avg_vis.tif/F162007.v4b_web.stable_lights.avg_vis.tif')
nightlights2009 <- raster('~/F162009.v4/F162009.v4b_web.stable_lights.avg_vis.tif/F162009.v4b_web.stable_lights.avg_vis.tif')
syria_shape<-readOGR(dsn="~/kakm_remotesensing_replicationcode/", layer="SYR_adm0") ##Change the dsn here to where you have it stored.
nightlights2007<-crop(nightlights2007,syria_shape)
nightlights2009<-crop(nightlights2009,syria_shape)
extent(nightlights2009)
extent(nightlights2007) 
origin(nightlights2009)<-0
origin(nightlights2007)<-0

nightlights0907<-nightlights2009-nightlights2007

####TABLE 1: Detecting Shift across F16 Satellite
nightlights2004 <- raster('~/F162004.v4/F162004.v4b_web.stable_lights.avg_vis.tif/F162004.v4b_web.stable_lights.avg_vis.tif')
nightlights2005 <- raster('~/F162005.v4/F162005.v4b_web.stable_lights.avg_vis.tif/F162005.v4b_web.stable_lights.avg_vis.tif')
nightlights2006 <- raster('~/F162006.v4/F162006.v4b_web.stable_lights.avg_vis.tif/F162006.v4b_web.stable_lights.avg_vis.tif')
nightlights2008 <- raster('~/F162008.v4/F162008.v4b_web.stable_lights.avg_vis.tif/F162008.v4b_web.stable_lights.avg_vis.tif')
nightlights2004<-crop(nightlights2004,syria_shape)
nightlights2005<-crop(nightlights2005,syria_shape)
nightlights2006<-crop(nightlights2006,syria_shape)
nightlights2008<-crop(nightlights2008,syria_shape)
origin(nightlights2004)<-0
origin(nightlights2005)<-0
origin(nightlights2006)<-0
origin(nightlights2008)<-0
corr0405<-rasterCorrelation(nightlights2004,nightlights2005,s=5)
plot(corr0405)
corr0405[is.na(corr0405[])] <- NA
values(corr0405)[values(corr0405) > 1] = NA
values(corr0405)[values(corr0405) < -1] = NA
cellStats(corr0405,stat='mean')
corr0406<-rasterCorrelation(nightlights2004,nightlights2006,s=5)
plot(corr0406)
corr0406[is.na(corr0406[])] <- NA
values(corr0406)[values(corr0406) > 1] = NA
values(corr0406)[values(corr0406) < -1] = NA
cellStats(corr0406,stat='mean')
corr0407<-rasterCorrelation(nightlights2004,nightlights2007,s=5)
plot(corr0407)
corr0407[is.na(corr0407[])] <- NA
values(corr0407)[values(corr0407) > 1] = NA
values(corr0407)[values(corr0407) < -1] = NA
cellStats(corr0407,stat='mean')
corr0408<-rasterCorrelation(nightlights2004,nightlights2008,s=5)
plot(corr0408)
corr0408[is.na(corr0408[])] <- NA
values(corr0408)[values(corr0408) > 1] = NA
values(corr0408)[values(corr0408) < -1] = NA
cellStats(corr0408,stat='mean')
corr0409<-rasterCorrelation(nightlights2004,nightlights2009,s=5)
plot(corr0409)
corr0409[is.na(corr0409[])] <- NA
values(corr0409)[values(corr0409) > 1] = NA
values(corr0409)[values(corr0409) < -1] = NA
cellStats(corr0409,stat='mean')
corr0506<-rasterCorrelation(nightlights2005,nightlights2006,s=5)
plot(corr0506)
corr0506[is.na(corr0506[])] <- NA
values(corr0506)[values(corr0506) > 1] = NA
values(corr0506)[values(corr0506) < -1] = NA
cellStats(corr0506,stat='mean')
corr0507<-rasterCorrelation(nightlights2005,nightlights2007,s=5)
plot(corr0507)
corr0507[is.na(corr0507[])] <- NA
values(corr0507)[values(corr0507) > 1] = NA
values(corr0507)[values(corr0507) < -1] = NA
cellStats(corr0507,stat='mean')
corr0508<-rasterCorrelation(nightlights2005,nightlights2008,s=5)
plot(corr0508)
corr0508[is.na(corr0508[])] <- NA
values(corr0508)[values(corr0508) > 1] = NA
values(corr0508)[values(corr0508) < -1] = NA
cellStats(corr0508,stat='mean')
corr0509<-rasterCorrelation(nightlights2005,nightlights2009,s=5)
plot(corr0509)
corr0509[is.na(corr0509[])] <- NA
values(corr0509)[values(corr0509) > 1] = NA
values(corr0509)[values(corr0509) < -1] = NA
cellStats(corr0509,stat='mean')
corr0607<-rasterCorrelation(nightlights2006,nightlights2007,s=5)
plot(corr0607)
corr0607[is.na(corr0607[])] <- NA
values(corr0607)[values(corr0607) > 1] = NA
values(corr0607)[values(corr0607) < -1] = NA
cellStats(corr0607,stat='mean')
corr0608<-rasterCorrelation(nightlights2006,nightlights2008,s=5)
plot(corr0608)
corr0608[is.na(corr0608[])] <- NA
values(corr0608)[values(corr0608) > 1] = NA
values(corr0608)[values(corr0608) < -1] = NA
cellStats(corr0608,stat='mean')
corr0609<-rasterCorrelation(nightlights2006,nightlights2009,s=5)
plot(corr0609)
corr0609[is.na(corr0609[])] <- NA
values(corr0609)[values(corr0609) > 1] = NA
values(corr0609)[values(corr0609) < -1] = NA
cellStats(corr0609,stat='mean')

corr0708<-rasterCorrelation(nightlights2007,nightlights2008,s=5)
plot(corr0708)
corr0708[is.na(corr0708[])] <- NA
values(corr0708)[values(corr0708) > 1] = NA
values(corr0708)[values(corr0708) < -1] = NA
cellStats(corr0708,stat='mean')
corr0809<-rasterCorrelation(nightlights2008,nightlights2009,s=5)
plot(corr0809)
corr0709[is.na(corr0809[])] <- NA
values(corr0809)[values(corr0809) > 1] = NA
values(corr0809)[values(corr0809) < -1] = NA
cellStats(corr0809,stat='mean')
corr0709<-rasterCorrelation(nightlights2007,nightlights2009,s=5)
plot(corr0709)
corr0709[is.na(corr0709[])] <- NA
values(corr0709)[values(corr0709) > 1] = NA
values(corr0709)[values(corr0709) < -1] = NA
cellStats(corr0709,stat='mean')






###Calculating shift###
nightlights2009shift<-raster::shift(nightlights2009,dx=0.0043894,dy=0.015704)
#nightlights2009shift <- projectRaster(nightlights2009,nightlights2007,method = 'bilinear')
origin(nightlights2009shift)<-0
nightlights0907shift<-nightlights2009shift-nightlights2007
plot(nightlights0907shift)


corr0709shift<-rasterCorrelation(nightlights2007,nightlights2009shift,s=5)
plot(corr0709shift)
corr0709shift[is.na(corr0709shift[])] <- NA
values(corr0709shift)[values(corr0709shift) > 1] = NA
values(corr0709shift)[values(corr0709shift) < -1] = NA
cellStats(corr0709shift,stat='mean')

corr0409shift<-rasterCorrelation(nightlights2004,nightlights2009shift,s=5)
plot(corr0409shift)
corr0409shift[is.na(corr0409shift[])] <- NA
values(corr0409shift)[values(corr0409shift) > 1] = NA
values(corr0409shift)[values(corr0409shift) < -1] = NA
cellStats(corr0409shift,stat='mean')

corr0509shift<-rasterCorrelation(nightlights2005,nightlights2009shift,s=5)
plot(corr0509shift)
corr0509shift[is.na(corr0509shift[])] <- NA
values(corr0509shift)[values(corr0509shift) > 1] = NA
values(corr0509shift)[values(corr0509shift) < -1] = NA
cellStats(corr0509shift,stat='mean')

corr0609shift<-rasterCorrelation(nightlights2006,nightlights2009shift,s=5)
plot(corr0609shift)
corr0609shift[is.na(corr0609shift[])] <- NA
values(corr0609shift)[values(corr0609shift) > 1] = NA
values(corr0609shift)[values(corr0609shift) < -1] = NA
cellStats(corr0609shift,stat='mean')

corr0809shift<-rasterCorrelation(nightlights2008,nightlights2009shift,s=5)
plot(corr0809shift)
corr0809shift[is.na(corr0809shift[])] <- NA
values(corr0809shift)[values(corr0809shift) > 1] = NA
values(corr0809shift)[values(corr0809shift) < -1] = NA
cellStats(corr0809shift,stat='mean')


writeRaster(nightlights0907shift,'nightlights0907shift',format="GTiff",overwrite=TRUE)
syr_adm1<-readOGR(dsn="~/kakm_remotesensing_replicationcode/", layer="SYR_adm1")
city_names<-readOGR(dsn="~/kakm_remotesensing_replicationcode/", layer="city_names")
bua_l4 <- readOGR(dsn="~/kakm_remotesensing_replicationcode/syr_admin_shp_utf8_170601", layer="syr_ppla_bua")
city_names<-subset(bua_l4,NAME_EN=='Lattakia'| NAME_EN=='Homs' | NAME_EN=='Hama' | NAME_EN=='Tartous' | NAME_EN=='Banyas')
plot(city_names)
pointLabel(coordinates(city_names),labels=city_names$NAME_EN,col="red",offset=100,cex=2)
###FIGURE 1####
attach(mtcars)
par(mfrow=c(2,3),mai = c(.005, 0.05, 0.15, 0.05), mar=c(0,1,1,1))
plot(nightlights2007,col=colorRampPalette(c("black", "white"))(255),axes=FALSE,xlim = c(35.7,37.2), ylim = c(34.5, 35.7),legend=F)
plot(city_names,col="transparent",border="green",add=T)
title("a) 2007 Composite", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(nightlights2009,col=colorRampPalette(c("black", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE,legend=F)
plot(city_names,col="transparent",border="green",add=T)
title("b) 2009 Composite", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(nightlights2009shift,col=colorRampPalette(c("black", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
plot(city_names,col="transparent",border="green",add=T)
title("c) 2009 Composite Corrected", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(bua_l4,xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE,border="gray")
title("d) Built-up Areas", line = 0.25)
plot(syr_adm1,add=T)
plot(city_names,col="blue",add=T)
pointLabel(coordinates(city_names),labels=city_names$NAME_EN,col="brown",offset=1000,cex=1.75)
map.scale(x=35.7, y= 34.625, ratio=FALSE, relwidth=0.25)
plot(nightlights0907,col=colorRampPalette(c("blue", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
title("e) Change from 2007 to 2009 Unshifted", line = 0.25)
plot(city_names,col="transparent",border="green",add=T)
plot(nightlights0907shift,col=colorRampPalette(c("blue", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
title("f) Change from 2007 to 2009 Shifted", line = 0.25)
plot(city_names,col="transparent",border="green",add=T)
detach(mtcars)






map.scale2 <- map.scale
fix(map.scale2)
#change line 1 to: function (x, y, relwidth = 0.15, metric = TRUE, ratio = TRUE, linecol="black",
#change line 42 to: lines(linexy,col=linecol)

###FIGURE 2####
attach(mtcars)
par(mfrow=c(1,3),mai = c(.005, 0.05, 0.15, 0.05), mar=c(0,1,1,1))
qamishli_limit<-readOGR(dsn="~/kakm_remotesensing_replicationcode/", layer="qamishlilimit")
bua_q<-crop(bua_l4,qamishli_limit)
nightlights2007q <-crop(nightlights2007,qamishli_limit)
plot(nightlights2007q,col=colorRampPalette(c("black", "white"))(255),axes=FALSE,legend=F)
plot(bua_q,axes=FALSE,border="green",add=T)
plot(syria_shape,border="red",lwd=2,add=T)
title("a) al-Qamishli: 2007 Composite", line = 0.5 ,cex.main=2)
map.scale2(x= 41.135, y= 36.9865, ratio=FALSE, col="white", linecol="white", relwidth=0.2)
symbols(y =37.0227761953, x =  41.2078464292, circles = 1, add = TRUE,
        inches = 0.06, bg = "green")
pointLabel(y =37.0227761953, x =  41.2078464292,labels= "2007",col="green",offset=1500,cex=1.5)
nightlights2009q <-crop(nightlights2009,qamishli_limit)
plot(nightlights2009q,col=colorRampPalette(c("black", "white"))(255),axes=FALSE,legend=F)
plot(bua_q,axes=FALSE,border="green",add=T)
plot(syria_shape,border="red",lwd=2,add=T)
title("b) al-Qamishli: 2009 Composite", line = 0.5,cex.main=2)
symbols(y =37.0227761953, x =  41.2078464292, circles = 1, add = TRUE,
        inches = 0.06, bg = "orange")
pointLabel(y =37.0227761953, x =  41.2078464292,labels= "2007",col="orange",offset=1500,cex=1.5)
symbols(y =37.0083265569, x =  41.2018257465, circles = 1, add = TRUE,
        inches = 0.06, bg = "green")
pointLabel(y =37.0083265569, x =  41.2018257465,labels= "2009",col="green",offset=1500,cex=1.5)
nightlights2009qshift <-crop(nightlights2009shift,qamishli_limit)
plot(nightlights2009qshift,col=colorRampPalette(c("black", "white"))(255),axes=FALSE,legend=F)
plot(bua_q,axes=FALSE,border="green",add=T)
plot(syria_shape,border="red",lwd=2,add=T)
title("c) al-Qamishli: 2009 Shifted", line = 0.5,cex.main=2)
symbols(y =37.0227761953, x =  41.2078464292, circles = 1, add = TRUE,
        inches = 0.06, bg = "orange")
pointLabel(y =37.0227761953, x =  41.2078464292,labels= "2007",col="orange",offset=1500,cex=1.5)
symbols(y =37.0083265569, x =  41.2018257465, circles = 1, add = TRUE,
        inches = 0.06, bg = "orange")
pointLabel(y =37.0083265569, x =  41.2018257465,labels= "2009",col="orange",offset=1500,cex=1.5)

detach(mtcars)









####FIGURE 3: Calculate Systematic Changes across Subdistricts####
nightlights_syschange<- nightlights0907-nightlights0907shift
extracted.l3.orig <- extract(nightlights0907, syr_adm3, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
extracted.l3.shifted <- extract(nightlights0907shift, syr_adm3, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
extracted.l3.syschange <- extract(nightlights_syschange, syr_adm3, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)

syr_adm3<-readOGR(dsn="~/kakm_remotesensing_replicationcode/syr_uncs-ocha_20130519_shp_UTF8", layer="syr_admin3")
m_2005 <- mapview(extracted.l3.syschange, 
                  zcol = "KILLED_SUM", 
                  layer.name = "")
m_2005
tm_shape(extracted.l3.orig)+ tm_layout(title="a) Change from 2007 to 2009 (Original)") + tm_borders() +tm_fill(col = 'layer', title = 'Mean Change (DNs)',n=10)
tm_shape(extracted.l3.shifted)+ tm_layout(title="d) Change from 2007 to 2009 (Shifted)")+ tm_borders()+tm_fill(col = 'layer', title = 'Mean Change (DNs)',n=10)
tm_shape(extracted.l3.syschange)+ tm_layout(title="b) Difference from Original to Shifted")+ tm_borders()+tm_fill(col = 'layer', title = 'Mean Difference (DNs)',n=10)
merged<-data.frame(xx$l3_pcode,xx$dum_fat_total_25)
merged$PCODE<-merged$xx.l3_pcode
merged$xx.l3_pcode<-NULL

syr_adm3@data<-left_join(syr_adm3@data,merged,by="PCODE")
syr_adm3<-subset(syr_adm3, ADMIN1_EN != "Quneitra")
tm_shape(syr_adm3)+ tm_layout(title="e) Deaths from Syrian Government Violence")+ tm_borders()+tm_fill( 'xx.dum_fat_total_25', title = 'March 2011 to November 2012',palette = "Reds", style="fixed",breaks =c(-1,0.5,1) ,labels = c("Less than 25 deaths", "At least 25 deaths"))
###Zoomed to Damascus xlim = c(35.7,37.2), ylim = c(34.5, 35.7)

Damascus <- crop(syr_adm3, c(35.5,38,32.3, 34))
plot(Damascus)
tm_shape(Damascus)+ tm_layout(title="f) Deaths from Government Violence (Rural Damascus)",title.size =5 )+ tm_borders()+tm_fill( 'xx.dum_fat_total_25', title = 'March 2011 to November 2012',palette = "Reds", style="fixed",breaks =c(-1,0.5,1) ,labels = c("Less than 25 deaths", "At least 25 deaths"))
extracted.l3.syschange_rd <- extract(nightlights_syschange, Damascus, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
tm_shape(extracted.l3.syschange_rd)+ tm_layout(title="c) Difference from Original to Shifted (Rural Damascus)")+ tm_borders()+tm_fill(col = 'layer', title = 'Mean Difference (DNs)',n=10)

###Remove areas surrounded by gas flare lights
syr_adm3<-readOGR(dsn="~/kakm_remotesensing_replicationcode/syr_uncs-ocha_20130519_shp_UTF8", layer="syr_admin3")
gas_flares_area<-readOGR(dsn="~/kakm_remotesensing_replicationcode/", layer="Flares_Syria_1")
syr_adm3_noflares2<-syr_adm3-gas_flares_area
extracted.l3.syschange.noflares <- extract(nightlights_syschange, syr_adm3_noflares2, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
avg.syschange.shift<-extracted.l3.syschange@data$layer
avg.syschange.noflares.shift<-extracted.l3.syschange.noflares@data$layer

syschange<-cbind(syr_adm3@data,avg.syschange.shift)
syschange<-cbind(syschange,avg.syschange.noflares.shift)

syschange$l3_pcode<-syschange$PCODE
syschange<-data.frame(syschange$l3_pcode,syschange$avg.syschange.shift,syschange$avg.syschange.noflares.shift)
syschange$l3_pcode<-syschange$syschange.l3_pcode
syschange$avg.syschange.shift<-syschange$syschange.avg.syschange.shift
syschange$avg.syschange.noflares.shift<-syschange$syschange.avg.syschange.noflares.shift


xx$nosatnoflares0907.shift<-NULL
xx$noflares0907.shift<-NULL
xx$syr_merge_0907nosatnoflares.shift.avg.nosat0907.noflares.shift<-NULL
xx$syr_merge_0907nosatnoflares.shift.PCODE<-NULL
xx$syr_merge_0907noflares.shift.avg.0907.noflares.shift<-NULL
xx$syr_merge_0907nosatnoflares.PCODE<-NULL
xx$syr_merge_0907noflares.shift.PCODE<-NULL
xx$orig0907.shift<-NULL
xx$nosat0907.shift<-NULL
xx$syr_merge_0907light.shift.avg.nosat0907orig.shift<-NULL
xx$syr_merge_0907light.shift.avg.nosat0907.shift<-NULL
xx$syr_merge_0907light.shift.l3_pcode<-NULL
xx$avg.syschange.noflares.shift<-NULL
xx$avg.syschange.shift<-NULL
xx$syschange.avg.syschange.noflares.shift<-NULL
xx$syschange.avg.syschange.shift<-NULL
xx$syschange.l3_pcode<-NULL


xx <- merge(xx, syschange,by="l3_pcode",all= TRUE)
###TABLE 4####

syschange <- lm(syschange.avg.syschange.shift ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + factor(gov_id), data=xx)
summary(syschange)
vcov_syschange <- cluster.vcov(syschange, cbind(xx$gov_id))
syschange<-round(coeftest(syschange, vcov_syschange),3)

syschangeflares <- lm(syschange.avg.syschange.noflares.shift ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + factor(gov_id), data=xx)
summary(syschangeflares)
vcov_syschangeflares <- cluster.vcov(syschangeflares, cbind(xx$gov_id))
syschangeflares<-round(coeftest(syschangeflares, vcov_syschangeflares),3)
syschangeflares


stargazer(syschange,syschangeflares)

####TABLE 3: Replication of DJB Analysis####

xx$syr_merge_0907light.shift.l3_pcode<-NULL
xx$syr_merge_0907light.shift.avg.nosat0907.shift<-NULL
xx$syr_merge_0907light.shift.avg.nosat0907orig.shift<-NULL
xx$nosat0907.shift<-NULL
xx$orig0907.shift<-NULL
xx$noflares0907.shift<-NULL
xx$syr_merge_0907noflares.shift.avg.0907.noflares.shift<-NULL
xx$syr_merge_0907noflares.shift.PCODE<-NULL
xx$syr_merge_0907nosatnoflares.shift.PCODE<-NULL
xx$syr_merge_0907nosatnoflares.shift.avg.nosat0907.noflares.shift<-NULL
xx$nosatnoflares0907.shift<-NULL

nightlights2007[nightlights2007>60]<-NA
nightlights0907shiftnosat<-nightlights2009-nightlights2007

extracted.l3.nosat.shift <- extract(nightlights0907shiftnosat, syr_adm3, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
extracted.l3.orig.shift <- extract(nightlights0907shift, syr_adm3, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
avg.nosat0907.shift<-extracted.l3.nosat.shift@data$layer
avg.nosat0907orig.shift<-extracted.l3.orig.shift@data$layer

syr_merge_0907light.shift<-cbind(syr_adm3@data,avg.nosat0907.shift)
syr_merge_0907light.shift<-cbind(syr_merge_0907light.shift,avg.nosat0907orig.shift)

syr_merge_0907light.shift$l3_pcode<-syr_merge_0907light.shift$PCODE
nosat0907.shift<-data.frame(syr_merge_0907light.shift$l3_pcode,syr_merge_0907light.shift$avg.nosat0907.shift,syr_merge_0907light.shift$avg.nosat0907orig.shift)
nosat0907.shift$l3_pcode<-nosat0907.shift$syr_merge_0907light.shift.l3_pcode
nosat0907.shift$nosat0907.shift<-nosat0907.shift$syr_merge_0907light.shift.avg.nosat0907.shift
nosat0907.shift$orig0907.shift<-nosat0907.shift$syr_merge_0907light.shift.avg.nosat0907orig.shift



xx <- merge(xx, nosat0907.shift,by="l3_pcode",all= TRUE)
names(xx)

base <- glm(dum_fat_total_25 ~ sc_emplgov + sunni + alawites + sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + ligmean_change_0907
            + factor(gov_id), family=binomial(link="logit"),data=xx)
vcov_base <- cluster.vcov(base, cbind(xx$gov_id))
base<-round(coeftest(base, vcov_base),3)

base.shift <- glm(dum_fat_total_25 ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + orig0907.shift+ factor(gov_id), family=binomial(link="logit"), data=xx)
vcov_base <- cluster.vcov(base.shift, cbind(xx$gov_id))
base.shift<-round(coeftest(base.shift, vcov_base),3)
base.shift

nosat0907.shift <- glm(dum_fat_total_25 ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + nosat0907.shift+ factor(gov_id), family=binomial(link="logit"), data=xx)
vcov_base <- cluster.vcov(nosat0907.shift, cbind(xx$gov_id))
nosat0907.shift<-round(coeftest(nosat0907.shift, vcov_base),3)
nosat0907.shift

###Remove areas surrounded by gas flare lights
gas_flares_area<-readOGR(dsn="~/kakm_remotesensing_replicationcode/", layer="Flares_Syria_1")
plot(nightlights0907nosat)
syr_adm3_noflares2<-syr_adm3-gas_flares_area
plot(syr_adm3_noflares2)
extracted.l3.noflares.shift <- extract(nightlights0907shift, syr_adm3_noflares2, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
avg.0907.noflares.shift<-extracted.l3.noflares.shift@data$layer
syr_merge_0907noflares.shift<-cbind(syr_adm3_noflares2@data,avg.0907.noflares.shift)
noflares0907.shift<-data.frame(syr_merge_0907noflares.shift$PCODE,syr_merge_0907noflares.shift$avg.0907.noflares.shift)
noflares0907.shift$l3_pcode<-noflares0907.shift$syr_merge_0907noflares.shift.PCODE
noflares0907.shift$noflares0907.shift<-noflares0907.shift$syr_merge_0907noflares.shift.avg.0907.noflares.shift
xx <- merge(xx, noflares0907.shift,by="l3_pcode",all= TRUE)

noflares0907.shift <- glm(dum_fat_total_25 ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + noflares0907.shift+ factor(gov_id), family=binomial(link="logit"), data=xx)
vcov_base <- cluster.vcov(noflares0907.shift, cbind(xx$gov_id))
noflares0907.shift<-round(coeftest(noflares0907.shift, vcov_base),3)
noflares0907.shift
xx

###Remove areas surrounded by gas flare lights from nonsaturated only
extracted.l3.nosat.noflares.shift <- extract(nightlights0907shiftnosat, syr_adm3_noflares2, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
avg.nosat0907.noflares.shift<-extracted.l3.nosat.noflares.shift@data$layer
syr_merge_0907nosatnoflares.shift<-cbind(syr_adm3_noflares2@data,avg.nosat0907.noflares.shift)
nosatnoflares0907.shift<-data.frame(syr_merge_0907nosatnoflares.shift$PCODE,syr_merge_0907nosatnoflares.shift$avg.nosat0907.noflares.shift)
nosatnoflares0907.shift$l3_pcode<-nosatnoflares0907.shift$syr_merge_0907nosatnoflares.shift.PCODE
nosatnoflares0907.shift$nosatnoflares0907.shift<-nosatnoflares0907.shift$syr_merge_0907nosatnoflares.shift.avg.nosat0907.noflares.shift
xx <- merge(xx, nosatnoflares0907.shift,by="l3_pcode",all= TRUE)



nosatnoflares0907.shift <- glm(dum_fat_total_25 ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + nosatnoflares0907.shift+factor(gov_id), family=binomial(link="logit"), data=xx)
vcov_base <- cluster.vcov(nosatnoflares0907.shift, cbind(xx$gov_id))
nosatnoflares0907.shift<-round(coeftest(nosatnoflares0907.shift, vcov_base),3)
nosatnoflares0907.shift


stargazer(base, base.shift,nosat0907.shift, noflares0907.shift,nosatnoflares0907.shift,
          title            = "Replication of De Juan and Bank (2015) Applying Corrective Shift to 2009 Lights Map",
          covariate.labels = c("Gov. Employees", "Sunni", "Alawi",
                               "School Enrollment", "Border Dist. (log)", "Urbanization", "Electrification", "Pct. Unemployed", "Road Density", "Population (log)", " Lights Change (Original) ",
                               "Lights Change (Shifted)", "Lights Change (Shifted, No Saturation)","Lights Change (Shifted, No Flares)", "Lights Change (Shifted, No Sat. No Flares)"),
          dep.var.caption  = "25 or more deaths in sub-district (binary)")





####Appendix####

###TABLE 1: Detecting Shift across F10 Satellite

nightlights1992 <- raster('~/F101992.v4/F101992.v4b_web.stable_lights.avg_vis.tif/F101992.v4b_web.stable_lights.avg_vis.tif')
nightlights1993 <- raster('~/F101993.v4/F101993.v4b_web.stable_lights.avg_vis.tif/F101993.v4b_web.stable_lights.avg_vis.tif')
nightlights1994 <- raster('~/F101994.v4b_web.stable_lights.avg_vis.tif/F101994.v4b_web.stable_lights.avg_vis.tif')
nightlights1992<-crop(nightlights1992,syria_shape)
nightlights1993<-crop(nightlights1993,syria_shape)
nightlights1994<-crop(nightlights1994,syria_shape)
origin(nightlights1992)<-0
origin(nightlights1993)<-0
origin(nightlights1994)<-0

corr9293<-rasterCorrelation(nightlights1992,nightlights1993,s=5)
plot(corr9293)
corr9293[is.na(corr9293[])] <- NA
values(corr9293)[values(corr9293) > 1] = NA
values(corr9293)[values(corr9293) < -1] = NA
cellStats(corr9293,stat='mean')

corr9294<-rasterCorrelation(nightlights1992,nightlights1994,s=5)
plot(corr9294)
corr9294[is.na(corr9294[])] <- NA
values(corr9294)[values(corr9294) > 1] = NA
values(corr9294)[values(corr9294) < -1] = NA
cellStats(corr9294,stat='mean')


corr9394<-rasterCorrelation(nightlights1993,nightlights1994,s=5)
plot(corr9394)
corr9394[is.na(corr9394[])] <- NA
values(corr9394)[values(corr9394) > 1] = NA
values(corr9394)[values(corr9394) < -1] = NA
cellStats(corr9394,stat='mean')

###TABLE 2: Detecting Shift across F12 Satellite

nightlights1994f12 <- raster('~/F121994.v4/F121994.v4b_web.stable_lights.avg_vis.tif/F121994.v4b_web.stable_lights.avg_vis.tif')
nightlights1995 <- raster('~/F121995.v4/F121995.v4b_web.stable_lights.avg_vis.tif/F121995.v4b_web.stable_lights.avg_vis.tif')
nightlights1996 <- raster('~/F121996.v4/F121996.v4b_web.stable_lights.avg_vis.tif/F121996.v4b_web.stable_lights.avg_vis.tif')
nightlights1997 <- raster('~/F121997.v4b_web.stable_lights.avg_vis.tif/F121997.v4b_web.stable_lights.avg_vis.tif')
nightlights1998 <- raster('~/F121998.v4b_web.stable_lights.avg_vis.tif/F121998.v4b_web.stable_lights.avg_vis.tif')
nightlights1999 <- raster('~/F121999.v4b_web.stable_lights.avg_vis.tif/F121999.v4b_web.stable_lights.avg_vis.tif')


nightlights1994f12<-crop(nightlights1994f12,syria_shape)
nightlights1995<-crop(nightlights1995,syria_shape)
nightlights1996<-crop(nightlights1996,syria_shape)
nightlights1997<-crop(nightlights1997,syria_shape)
nightlights1998<-crop(nightlights1999,syria_shape)
nightlights1999<-crop(nightlights1999,syria_shape)
origin(nightlights1994f12)<-0
origin(nightlights1995)<-0
origin(nightlights1996)<-0
origin(nightlights1997)<-0
origin(nightlights1998)<-0
origin(nightlights1999)<-0

corr9495<-rasterCorrelation(nightlights1994f12,nightlights1995,s=5)
plot(corr9495)
corr9495[is.na(corr9495[])] <- NA
values(corr9495)[values(corr9495) > 1] = NA
values(corr9495)[values(corr9495) < -1] = NA
cellStats(corr9495,stat='mean')

corr9496<-rasterCorrelation(nightlights1994f12,nightlights1996,s=5)
plot(corr9496)
corr9496[is.na(corr9496[])] <- NA
values(corr9496)[values(corr9496) > 1] = NA
values(corr9496)[values(corr9496) < -1] = NA
cellStats(corr9496,stat='mean')

corr9497<-rasterCorrelation(nightlights1994f12,nightlights1997,s=5)
plot(corr9497)
corr9497[is.na(corr9497[])] <- NA
values(corr9497)[values(corr9497) > 1] = NA
values(corr9497)[values(corr9497) < -1] = NA
cellStats(corr9497,stat='mean')

corr9498<-rasterCorrelation(nightlights1994f12,nightlights1998,s=5)
plot(corr9498)
corr9498[is.na(corr9498[])] <- NA
values(corr9498)[values(corr9498) > 1] = NA
values(corr9498)[values(corr9498) < -1] = NA
cellStats(corr9498,stat='mean')

corr9499<-rasterCorrelation(nightlights1994f12,nightlights1999,s=5)
plot(corr9499)
corr9499[is.na(corr9499[])] <- NA
values(corr9499)[values(corr9499) > 1] = NA
values(corr9499)[values(corr9499) < -1] = NA
cellStats(corr9499,stat='mean')

corr9596<-rasterCorrelation(nightlights1995,nightlights1996,s=5)
plot(corr9596)
corr9596[is.na(corr9596[])] <- NA
values(corr9596)[values(corr9596) > 1] = NA
values(corr9596)[values(corr9596) < -1] = NA
cellStats(corr9596,stat='mean')

corr9597<-rasterCorrelation(nightlights1995,nightlights1997,s=5)
plot(corr9597)
corr9597[is.na(corr9597[])] <- NA
values(corr9597)[values(corr9597) > 1] = NA
values(corr9597)[values(corr9597) < -1] = NA
cellStats(corr9597,stat='mean')


corr9598<-rasterCorrelation(nightlights1995,nightlights1998,s=5)
plot(corr9598)
corr9598[is.na(corr9598[])] <- NA
values(corr9598)[values(corr9598) > 1] = NA
values(corr9598)[values(corr9598) < -1] = NA
cellStats(corr9598,stat='mean')


corr9599<-rasterCorrelation(nightlights1995,nightlights1999,s=5)
plot(corr9599)
corr9599[is.na(corr9599[])] <- NA
values(corr9599)[values(corr9599) > 1] = NA
values(corr9599)[values(corr9599) < -1] = NA
cellStats(corr9599,stat='mean')

corr9697<-rasterCorrelation(nightlights1996,nightlights1997,s=5)
plot(corr9697)
corr9697[is.na(corr9697[])] <- NA
values(corr9697)[values(corr9697) > 1] = NA
values(corr9697)[values(corr9697) < -1] = NA
cellStats(corr9697,stat='mean')

corr9698<-rasterCorrelation(nightlights1996,nightlights1998,s=5)
plot(corr9698)
corr9698[is.na(corr9698[])] <- NA
values(corr9698)[values(corr9698) > 1] = NA
values(corr9698)[values(corr9698) < -1] = NA
cellStats(corr9698,stat='mean')

corr9699<-rasterCorrelation(nightlights1996,nightlights1999,s=5)
plot(corr9699)
corr9699[is.na(corr9699[])] <- NA
values(corr9699)[values(corr9699) > 1] = NA
values(corr9699)[values(corr9699) < -1] = NA
cellStats(corr9699,stat='mean')

corr9798<-rasterCorrelation(nightlights1997,nightlights1998,s=5)
plot(corr9798)
corr9798[is.na(corr9798[])] <- NA
values(corr9798)[values(corr9798) > 1] = NA
values(corr9798)[values(corr9798) < -1] = NA
cellStats(corr9798,stat='mean')

corr9799<-rasterCorrelation(nightlights1997,nightlights1999,s=5)
plot(corr9799)
corr9799[is.na(corr9799[])] <- NA
values(corr9799)[values(corr9799) > 1] = NA
values(corr9799)[values(corr9799) < -1] = NA
cellStats(corr9799,stat='mean')

corr9899<-rasterCorrelation(nightlights1998,nightlights1999,s=5)
plot(corr9899)
corr9899[is.na(corr9899[])] <- NA
values(corr9899)[values(corr9899) > 1] = NA
values(corr9899)[values(corr9899) < -1] = NA
cellStats(corr9899,stat='mean')

###TABLE 3: Detecting Shift across F14 Satellite

nightlights1997f14 <- raster('~/F141997.v4/F141997.v4b_web.stable_lights.avg_vis.tif/F141997.v4b_web.stable_lights.avg_vis.tif')
nightlights1998f14 <- raster('~/F141998.v4/F141998.v4b_web.stable_lights.avg_vis.tif/F141998.v4b_web.stable_lights.avg_vis.tif')
nightlights1999f14 <- raster('~/F141999.v4/F141999.v4b_web.stable_lights.avg_vis.tif/F141999.v4b_web.stable_lights.avg_vis.tif')
nightlights2000 <- raster('~/F142000.v4b_web.stable_lights.avg_vis.tif/F142000.v4b_web.stable_lights.avg_vis.tif')
nightlights2001 <- raster('~/F142001.v4b_web.stable_lights.avg_vis.tif/F142001.v4b_web.stable_lights.avg_vis.tif')
nightlights2002 <- raster('~/F142002.v4b_web.stable_lights.avg_vis.tif/F142002.v4b_web.stable_lights.avg_vis.tif')
nightlights2003 <- raster('~/F142003.v4b_web.stable_lights.avg_vis.tif/F142003.v4b_web.stable_lights.avg_vis.tif')


nightlights1997f14<-crop(nightlights1997f14,syria_shape)
nightlights1998f14<-crop(nightlights1998f14,syria_shape)
nightlights1999f14<-crop(nightlights1999f14,syria_shape)
nightlights2000<-crop(nightlights2000,syria_shape)
nightlights2001<-crop(nightlights2001,syria_shape)
nightlights2002<-crop(nightlights2002,syria_shape)
nightlights2003<-crop(nightlights2003,syria_shape)

origin(nightlights1997f14)<-0
origin(nightlights1998f14)<-0
origin(nightlights1999f14)<-0
origin(nightlights2000)<-0
origin(nightlights2001)<-0
origin(nightlights2002)<-0
origin(nightlights2003)<-0


corr9798<-rasterCorrelation(nightlights1997f14,nightlights1998f14,s=5)
plot(corr9798)
corr9798[is.na(corr9798[])] <- NA
values(corr9798)[values(corr9798) > 1] = NA
values(corr9798)[values(corr9798) < -1] = NA
cellStats(corr9798,stat='mean')

corr9799<-rasterCorrelation(nightlights1997f14,nightlights1999f14,s=5)
plot(corr9799)
corr9799[is.na(corr9799[])] <- NA
values(corr9799)[values(corr9799) > 1] = NA
values(corr9799)[values(corr9799) < -1] = NA
cellStats(corr9799,stat='mean')

corr9700<-rasterCorrelation(nightlights1997f14,nightlights2000,s=5)
plot(corr9700)
corr9700[is.na(corr9700[])] <- NA
values(corr9700)[values(corr9700) > 1] = NA
values(corr9700)[values(corr9700) < -1] = NA
cellStats(corr9700,stat='mean')

corr9701<-rasterCorrelation(nightlights1997f14,nightlights2001,s=5)
plot(corr9701)
corr9701[is.na(corr9701[])] <- NA
values(corr9701)[values(corr9701) > 1] = NA
values(corr9701)[values(corr9701) < -1] = NA
cellStats(corr9701,stat='mean')

corr9702<-rasterCorrelation(nightlights1997f14,nightlights2002,s=5)
plot(corr9702)
corr9702[is.na(corr9702[])] <- NA
values(corr9702)[values(corr9702) > 1] = NA
values(corr9702)[values(corr9702) < -1] = NA
cellStats(corr9702,stat='mean')

corr9703<-rasterCorrelation(nightlights1997f14,nightlights2003,s=5)
plot(corr9703)
corr9703[is.na(corr9703[])] <- NA
values(corr9703)[values(corr9703) > 1] = NA
values(corr9703)[values(corr9703) < -1] = NA
cellStats(corr9703,stat='mean')


corr9899<-rasterCorrelation(nightlights1998f14,nightlights1999f14,s=5)
plot(corr9899)
corr9899[is.na(corr9899[])] <- NA
values(corr9899)[values(corr9899) > 1] = NA
values(corr9899)[values(corr9899) < -1] = NA
cellStats(corr9899,stat='mean')

corr9800<-rasterCorrelation(nightlights1998f14,nightlights2000,s=5)
plot(corr9800)
corr9800[is.na(corr9800[])] <- NA
values(corr9800)[values(corr9800) > 1] = NA
values(corr9800)[values(corr9800) < -1] = NA
cellStats(corr9800,stat='mean')


corr9801<-rasterCorrelation(nightlights1998f14,nightlights2001,s=5)
plot(corr9801)
corr9801[is.na(corr9801[])] <- NA
values(corr9801)[values(corr9801) > 1] = NA
values(corr9801)[values(corr9801) < -1] = NA
cellStats(corr9801,stat='mean')


corr9802<-rasterCorrelation(nightlights1998f14,nightlights2002,s=5)
plot(corr9802)
corr9802[is.na(corr9802[])] <- NA
values(corr9802)[values(corr9802) > 1] = NA
values(corr9802)[values(corr9802) < -1] = NA
cellStats(corr9802,stat='mean')


corr9803<-rasterCorrelation(nightlights1998f14,nightlights2003,s=5)
plot(corr9803)
corr9803[is.na(corr9803[])] <- NA
values(corr9803)[values(corr9803) > 1] = NA
values(corr9803)[values(corr9803) < -1] = NA
cellStats(corr9803,stat='mean')


corr9900<-rasterCorrelation(nightlights1999f14,nightlights2000,s=5)
plot(corr9900)
corr9900[is.na(corr9900[])] <- NA
values(corr9900)[values(corr9900) > 1] = NA
values(corr9900)[values(corr9900) < -1] = NA
cellStats(corr9900,stat='mean')


corr9901<-rasterCorrelation(nightlights1999f14,nightlights2001,s=5)
plot(corr9901)
corr9901[is.na(corr9901[])] <- NA
values(corr9901)[values(corr9901) > 1] = NA
values(corr9901)[values(corr9901) < -1] = NA
cellStats(corr9901,stat='mean')


corr9902<-rasterCorrelation(nightlights1999f14,nightlights2002,s=5)
plot(corr9902)
corr9902[is.na(corr9902[])] <- NA
values(corr9902)[values(corr9902) > 1] = NA
values(corr9902)[values(corr9902) < -1] = NA
cellStats(corr9902,stat='mean')


corr9903<-rasterCorrelation(nightlights1999f14,nightlights2003,s=5)
plot(corr9903)
corr9903[is.na(corr9903[])] <- NA
values(corr9903)[values(corr9903) > 1] = NA
values(corr9903)[values(corr9903) < -1] = NA
cellStats(corr9903,stat='mean')

corr0001<-rasterCorrelation(nightlights2000,nightlights2001,s=5)
plot(corr0001)
corr0001[is.na(corr0001[])] <- NA
values(corr0001)[values(corr0001) > 1] = NA
values(corr0001)[values(corr0001) < -1] = NA
cellStats(corr0001,stat='mean')

corr0002<-rasterCorrelation(nightlights2000,nightlights2002,s=5)
plot(corr0002)
corr0002[is.na(corr0002[])] <- NA
values(corr0002)[values(corr0002) > 1] = NA
values(corr0002)[values(corr0002) < -1] = NA
cellStats(corr0002,stat='mean')

corr0003<-rasterCorrelation(nightlights2000,nightlights2003,s=5)
plot(corr0003)
corr0003[is.na(corr0003[])] <- NA
values(corr0003)[values(corr0003) > 1] = NA
values(corr0003)[values(corr0003) < -1] = NA
cellStats(corr0003,stat='mean')

corr0102<-rasterCorrelation(nightlights2001,nightlights2002,s=5)
plot(corr0102)
corr0102[is.na(corr0102[])] <- NA
values(corr0102)[values(corr0102) > 1] = NA
values(corr0102)[values(corr0102) < -1] = NA
cellStats(corr0102,stat='mean')

corr0103<-rasterCorrelation(nightlights2001,nightlights2003,s=5)
plot(corr0103)
corr0103[is.na(corr0103[])] <- NA
values(corr0103)[values(corr0103) > 1] = NA
values(corr0103)[values(corr0103) < -1] = NA
cellStats(corr0103,stat='mean')

corr0203<-rasterCorrelation(nightlights2002,nightlights2003,s=5)
plot(corr0203)
corr0203[is.na(corr0203[])] <- NA
values(corr0203)[values(corr0203) > 1] = NA
values(corr0203)[values(corr0203) < -1] = NA
cellStats(corr0203,stat='mean')

###TABLE 4: Detecting Shift across F15 Satellite


nightlights2000f15 <- raster('~/F152000.v4/F152000.v4b_web.stable_lights.avg_vis.tif/F152000.v4b_web.stable_lights.avg_vis.tif')
nightlights2001f15 <- raster('~/F152001.v4/F152001.v4b_web.stable_lights.avg_vis.tif/F152001.v4b_web.stable_lights.avg_vis.tif')
nightlights2002f15 <- raster('~/F152002.v4/F152002.v4b_web.stable_lights.avg_vis.tif/F152002.v4b_web.stable_lights.avg_vis.tif')
nightlights2003f15 <- raster('~/F152003.v4/F152003.v4b_web.stable_lights.avg_vis.tif/F152003.v4b_web.stable_lights.avg_vis.tif')
nightlights2004f15 <- raster('~/F152004.v4b_web.stable_lights.avg_vis.tif')
nightlights2005f15 <- raster('~/F152005.v4b_web.stable_lights.avg_vis.tif/F152005.v4b_web.stable_lights.avg_vis.tif')
nightlights2006f15 <- raster('~/F152006.v4b_web.stable_lights.avg_vis.tif/F152006.v4b_web.stable_lights.avg_vis.tif')
nightlights2007f15 <- raster('~/F152007.v4b_web.stable_lights.avg_vis.tif/F152007.v4b_web.stable_lights.avg_vis.tif')

nightlights2000f15<-crop(nightlights2000f15,syria_shape)
nightlights2001f15<-crop(nightlights2001f15,syria_shape)
nightlights2002f15<-crop(nightlights2002f15,syria_shape)
nightlights2003f15<-crop(nightlights2003f15,syria_shape)
nightlights2004f15<-crop(nightlights2004f15,syria_shape)
nightlights2005f15<-crop(nightlights2005f15,syria_shape)
nightlights2006f15<-crop(nightlights2006f15,syria_shape)
nightlights2007f15<-crop(nightlights2007f15,syria_shape)

origin(nightlights2000f15)<-0
origin(nightlights2001f15)<-0
origin(nightlights2002f15)<-0
origin(nightlights2003f15)<-0
origin(nightlights2004f15)<-0
origin(nightlights2005f15)<-0
origin(nightlights2006f15)<-0
origin(nightlights2007f15)<-0


corr0001<-rasterCorrelation(nightlights2000f15,nightlights2001f15,s=5)
plot(corr0001)
corr0001[is.na(corr0001[])] <- NA
values(corr0001)[values(corr0001) > 1] = NA
values(corr0001)[values(corr0001) < -1] = NA
cellStats(corr0001,stat='mean')

corr0002<-rasterCorrelation(nightlights2000f15,nightlights2002f15,s=5)
plot(corr0002)
corr0002[is.na(corr0002[])] <- NA
values(corr0002)[values(corr0002) > 1] = NA
values(corr0002)[values(corr0002) < -1] = NA
cellStats(corr0002,stat='mean')

corr0003<-rasterCorrelation(nightlights2000f15,nightlights2003f15,s=5)
plot(corr0003)
corr0003[is.na(corr0003[])] <- NA
values(corr0003)[values(corr0003) > 1] = NA
values(corr0003)[values(corr0003) < -1] = NA
cellStats(corr0003,stat='mean')

corr0004<-rasterCorrelation(nightlights2000f15,nightlights2004f15,s=5)
plot(corr0004)
corr0004[is.na(corr0004[])] <- NA
values(corr0004)[values(corr0004) > 1] = NA
values(corr0004)[values(corr0004) < -1] = NA
cellStats(corr0004,stat='mean')

corr0005<-rasterCorrelation(nightlights2000f15,nightlights2005f15,s=5)
plot(corr0005)
corr0005[is.na(corr0005[])] <- NA
values(corr0005)[values(corr0005) > 1] = NA
values(corr0005)[values(corr0005) < -1] = NA
cellStats(corr0005,stat='mean')

corr0006<-rasterCorrelation(nightlights2000f15,nightlights2006f15,s=5)
plot(corr0006)
corr0006[is.na(corr0006[])] <- NA
values(corr0006)[values(corr0006) > 1] = NA
values(corr0006)[values(corr0006) < -1] = NA
cellStats(corr0006,stat='mean')

corr0007<-rasterCorrelation(nightlights2000f15,nightlights2007f15,s=5)
plot(corr0007)
corr0007[is.na(corr0007[])] <- NA
values(corr0007)[values(corr0007) > 1] = NA
values(corr0007)[values(corr0007) < -1] = NA
cellStats(corr0007,stat='mean')

corr0102<-rasterCorrelation(nightlights2001f15,nightlights2002f15,s=5)
plot(corr0102)
corr0102[is.na(corr0102[])] <- NA
values(corr0102)[values(corr0102) > 1] = NA
values(corr0102)[values(corr0102) < -1] = NA
cellStats(corr0102,stat='mean')

corr0103<-rasterCorrelation(nightlights2001f15,nightlights2003f15,s=5)
plot(corr0103)
corr0103[is.na(corr0103[])] <- NA
values(corr0103)[values(corr0103) > 1] = NA
values(corr0103)[values(corr0103) < -1] = NA
cellStats(corr0103,stat='mean')

corr0104<-rasterCorrelation(nightlights2001f15,nightlights2004f15,s=5)
plot(corr0104)
corr0104[is.na(corr0104[])] <- NA
values(corr0104)[values(corr0104) > 1] = NA
values(corr0104)[values(corr0104) < -1] = NA
cellStats(corr0104,stat='mean')

corr0105<-rasterCorrelation(nightlights2001f15,nightlights2005f15,s=5)
plot(corr0105)
corr0105[is.na(corr0105[])] <- NA
values(corr0105)[values(corr0105) > 1] = NA
values(corr0105)[values(corr0105) < -1] = NA
cellStats(corr0105,stat='mean')

corr0106<-rasterCorrelation(nightlights2001f15,nightlights2006f15,s=5)
plot(corr0106)
corr0106[is.na(corr0106[])] <- NA
values(corr0106)[values(corr0106) > 1] = NA
values(corr0106)[values(corr0106) < -1] = NA
cellStats(corr0106,stat='mean')

corr0107<-rasterCorrelation(nightlights2001f15,nightlights2007f15,s=5)
plot(corr0107)
corr0107[is.na(corr0107[])] <- NA
values(corr0107)[values(corr0107) > 1] = NA
values(corr0107)[values(corr0107) < -1] = NA
cellStats(corr0107,stat='mean')

corr0203<-rasterCorrelation(nightlights2002f15,nightlights2003f15,s=5)
plot(corr0203)
corr0203[is.na(corr0203[])] <- NA
values(corr0203)[values(corr0203) > 1] = NA
values(corr0203)[values(corr0203) < -1] = NA
cellStats(corr0203,stat='mean')

corr0204<-rasterCorrelation(nightlights2002f15,nightlights2004f15,s=5)
plot(corr0204)
corr0204[is.na(corr0204[])] <- NA
values(corr0204)[values(corr0204) > 1] = NA
values(corr0204)[values(corr0204) < -1] = NA
cellStats(corr0204,stat='mean')

corr0205<-rasterCorrelation(nightlights2002f15,nightlights2005f15,s=5)
plot(corr0205)
corr0205[is.na(corr0205[])] <- NA
values(corr0205)[values(corr0205) > 1] = NA
values(corr0205)[values(corr0205) < -1] = NA
cellStats(corr0205,stat='mean')

corr0206<-rasterCorrelation(nightlights2002f15,nightlights2006f15,s=5)
plot(corr0206)
corr0206[is.na(corr0206[])] <- NA
values(corr0206)[values(corr0206) > 1] = NA
values(corr0206)[values(corr0206) < -1] = NA
cellStats(corr0206,stat='mean')

corr0207<-rasterCorrelation(nightlights2002f15,nightlights2007f15,s=5)
plot(corr0207)
corr0207[is.na(corr0207[])] <- NA
values(corr0207)[values(corr0207) > 1] = NA
values(corr0207)[values(corr0207) < -1] = NA
cellStats(corr0207,stat='mean')

corr0304<-rasterCorrelation(nightlights2003f15,nightlights2004f15,s=5)
plot(corr0304)
corr0304[is.na(corr0304[])] <- NA
values(corr0304)[values(corr0304) > 1] = NA
values(corr0304)[values(corr0304) < -1] = NA
cellStats(corr0304,stat='mean')

corr0305<-rasterCorrelation(nightlights2003f15,nightlights2005f15,s=5)
plot(corr0305)
corr0305[is.na(corr0305[])] <- NA
values(corr0305)[values(corr0305) > 1] = NA
values(corr0305)[values(corr0305) < -1] = NA
cellStats(corr0305,stat='mean')

corr0306<-rasterCorrelation(nightlights2003f15,nightlights2006f15,s=5)
plot(corr0306)
corr0306[is.na(corr0306[])] <- NA
values(corr0306)[values(corr0306) > 1] = NA
values(corr0306)[values(corr0306) < -1] = NA
cellStats(corr0306,stat='mean')

corr0307<-rasterCorrelation(nightlights2003f15,nightlights2007f15,s=5)
plot(corr0307)
corr0307[is.na(corr0307[])] <- NA
values(corr0307)[values(corr0307) > 1] = NA
values(corr0307)[values(corr0307) < -1] = NA
cellStats(corr0307,stat='mean')

corr0405<-rasterCorrelation(nightlights2004f15,nightlights2005f15,s=5)
plot(corr0405)
corr0405[is.na(corr0405[])] <- NA
values(corr0405)[values(corr0405) > 1] = NA
values(corr0405)[values(corr0405) < -1] = NA
cellStats(corr0405,stat='mean')

corr0406<-rasterCorrelation(nightlights2004f15,nightlights2006f15,s=5)
plot(corr0406)
corr0406[is.na(corr0406[])] <- NA
values(corr0406)[values(corr0406) > 1] = NA
values(corr0406)[values(corr0406) < -1] = NA
cellStats(corr0406,stat='mean')

corr0407<-rasterCorrelation(nightlights2004f15,nightlights2007f15,s=5)
plot(corr0407)
corr0407[is.na(corr0407[])] <- NA
values(corr0407)[values(corr0407) > 1] = NA
values(corr0407)[values(corr0407) < -1] = NA
cellStats(corr0407,stat='mean')

corr0506<-rasterCorrelation(nightlights2005f15,nightlights2006f15,s=5)
plot(corr0506)
corr0506[is.na(corr0506[])] <- NA
values(corr0506)[values(corr0506) > 1] = NA
values(corr0506)[values(corr0506) < -1] = NA
cellStats(corr0506,stat='mean')

corr0507<-rasterCorrelation(nightlights2005f15,nightlights2007f15,s=5)
plot(corr0507)
corr0507[is.na(corr0507[])] <- NA
values(corr0507)[values(corr0507) > 1] = NA
values(corr0507)[values(corr0507) < -1] = NA
cellStats(corr0507,stat='mean')

corr0607<-rasterCorrelation(nightlights2006f15,nightlights2007f15,s=5)
plot(corr0607)
corr0607[is.na(corr0607[])] <- NA
values(corr0607)[values(corr0607) > 1] = NA
values(corr0607)[values(corr0607) < -1] = NA
cellStats(corr0607,stat='mean')


###TABLE 5: Detecting Shift across F18 Satellite

nightlights2010 <- raster('~/F182010.v4/F182010.v4d_web.stable_lights.avg_vis.tif/F182010.v4d_web.stable_lights.avg_vis.tif')
nightlights2011 <- raster('~/F182011.v4c_web.stable_lights.avg_vis.tif/F182011.v4c_web.stable_lights.avg_vis.tif')
nightlights2012 <- raster('~/F182012.v4c_web.stable_lights.avg_vis.tif/F182012.v4c_web.stable_lights.avg_vis.tif')
nightlights2013 <- raster('~/F182013.v4c_web.stable_lights.avg_vis.tif/F182013.v4c_web.stable_lights.avg_vis.tif')
nightlights2010<-crop(nightlights2010,syria_shape)
nightlights2011<-crop(nightlights2011,syria_shape)
nightlights2012<-crop(nightlights2012,syria_shape)
nightlights2013<-crop(nightlights2013,syria_shape)
origin(nightlights2010)<-0
origin(nightlights2011)<-0
origin(nightlights2012)<-0
origin(nightlights2013)<-0

corr1011<-rasterCorrelation(nightlights2010,nightlights2011,s=5)
plot(corr1011)
corr1011[is.na(corr1011[])] <- NA
values(corr1011)[values(corr1011) > 1] = NA
values(corr1011)[values(corr1011) < -1] = NA
cellStats(corr1011,stat='mean')

corr1012<-rasterCorrelation(nightlights2010,nightlights2012,s=5)
plot(corr1012)
corr1012[is.na(corr1012[])] <- NA
values(corr1012)[values(corr1012) > 1] = NA
values(corr1012)[values(corr1012) < -1] = NA
cellStats(corr1012,stat='mean')

corr1013<-rasterCorrelation(nightlights2010,nightlights2013,s=5)
plot(corr1013)
corr1013[is.na(corr1013[])] <- NA
values(corr1013)[values(corr1013) > 1] = NA
values(corr1013)[values(corr1013) < -1] = NA
cellStats(corr1013,stat='mean')

corr1112<-rasterCorrelation(nightlights2011,nightlights2012,s=5)
plot(corr1112)
corr1112[is.na(corr1112[])] <- NA
values(corr1112)[values(corr1112) > 1] = NA
values(corr1112)[values(corr1112) < -1] = NA
cellStats(corr1112,stat='mean')

corr1113<-rasterCorrelation(nightlights2011,nightlights2013,s=5)
plot(corr1113)
corr1113[is.na(corr1113[])] <- NA
values(corr1113)[values(corr1113) > 1] = NA
values(corr1113)[values(corr1113) < -1] = NA
cellStats(corr1113,stat='mean')

corr1213<-rasterCorrelation(nightlights2012,nightlights2013,s=5)
plot(corr1213)
corr1213[is.na(corr1213[])] <- NA
values(corr1213)[values(corr1213) > 1] = NA
values(corr1213)[values(corr1213) < -1] = NA
cellStats(corr1213,stat='mean')


###Appendix 2: Visual Inspection of F16 Map Combinations other than 2007-2009###


###FIGURE 1: 2004 and 2009 ####

origin(nightlights2009)<-0
origin(nightlights2004)<-0
nightlights0904<-nightlights2009-nightlights2004
nightlights2009shift<-raster::shift(nightlights2009,dx=0.0043894,dy=0.015704)
origin(nightlights2009shift)<-0
origin(nightlights0904)<-0
nightlights0904shift<-nightlights2009shift-nightlights2004

attach(mtcars)
par(mfrow=c(2,2),mai = c(.005, 0.05, 0.15, 0.05), mar=c(0,1,1,1))
plot(nightlights2004,col=colorRampPalette(c("black", "white"))(255),axes=FALSE,xlim = c(35.7,37.2), ylim = c(34.5, 35.7),legend=F)
plot(city_names,col="transparent",border="green",add=T)
title("2004 Composite", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(nightlights2009,col=colorRampPalette(c("black", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
plot(city_names,col="transparent",border="green",add=T)
title("2009 Composite", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)


plot(bua_l4,xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE,border="gray")
title("Built-up Areas", line = 0.25)
plot(syr_adm1,add=T)
plot(city_names,col="blue",add=T)
pointLabel(coordinates(city_names),labels=city_names$NAME_EN,col="brown",offset=1000,cex=1.75)
map.scale(x=35.7, y= 34.625, ratio=FALSE, relwidth=0.25)
plot(nightlights0904,col=colorRampPalette(c("blue", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
title("Change from 2004 to 2009 Unshifted", line = 0.25)
plot(city_names,col="transparent",border="green",add=T)

detach(mtcars)



###FIGURE 2: 2005 and 2009 ####
origin(nightlights2009)<-0
origin(nightlights2005)<-0
nightlights0905<-nightlights2009-nightlights2005
nightlights2009shift<-raster::shift(nightlights2009,dx=0.0043894,dy=0.015704)
origin(nightlights2009shift)<-0
nightlights0905shift<-nightlights2009shift-nightlights2005

attach(mtcars)
par(mfrow=c(2,3),mai = c(.005, 0.05, 0.15, 0.05), mar=c(0,1,1,1))
plot(nightlights2005,col=colorRampPalette(c("black", "white"))(255),axes=FALSE,xlim = c(35.7,37.2), ylim = c(34.5, 35.7),legend=F)
plot(city_names,col="transparent",border="green",add=T)
title("2005 Composite", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(nightlights2009,col=colorRampPalette(c("black", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE,legend=F)
plot(city_names,col="transparent",border="green",add=T)
title("2009 Composite", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(nightlights2009shift,col=colorRampPalette(c("black", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
plot(city_names,col="transparent",border="green",add=T)
title("2009 Composite Corrected", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(bua_l4,xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE,border="gray")
title("Built-up Areas", line = 0.25)
plot(syr_adm1,add=T)
plot(city_names,col="blue",add=T)
pointLabel(coordinates(city_names),labels=city_names$NAME_EN,col="brown",offset=1000,cex=1.75)
map.scale(x=35.7, y= 34.625, ratio=FALSE, relwidth=0.25)
plot(nightlights0905,col=colorRampPalette(c("blue", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
title("Change from 2005 to 2009 Unshifted", line = 0.25)
plot(city_names,col="transparent",border="green",add=T)
plot(nightlights0905shift,col=colorRampPalette(c("blue", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
title("Change from 2005 to 2009 Shifted", line = 0.25)
plot(city_names,col="transparent",border="green",add=T)
detach(mtcars)

###FIGURE 3: 2006 and 2009 ####

origin(nightlights2009)<-0
origin(nightlights2006)<-0
nightlights0906<-nightlights2009-nightlights2006
nightlights2009shift<-raster::shift(nightlights2009,dx=0.0043894,dy=0.015704)
origin(nightlights2009shift)<-0
origin(nightlights0906)<-0
nightlights0906shift<-nightlights2009shift-nightlights2006

attach(mtcars)
par(mfrow=c(2,3),mai = c(.005, 0.05, 0.15, 0.05), mar=c(0,1,1,1))
plot(nightlights2006,col=colorRampPalette(c("black", "white"))(255),axes=FALSE,xlim = c(35.7,37.2), ylim = c(34.5, 35.7),legend=F)
plot(city_names,col="transparent",border="green",add=T)
title("2006 Composite", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(nightlights2009,col=colorRampPalette(c("black", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE,legend=F)
plot(city_names,col="transparent",border="green",add=T)
title("2009 Composite", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(nightlights2009shift,col=colorRampPalette(c("black", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
plot(city_names,col="transparent",border="green",add=T)
title("2009 Composite Corrected", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(bua_l4,xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE,border="gray")
title("Built-up Areas", line = 0.25)
plot(syr_adm1,add=T)
plot(city_names,col="blue",add=T)
pointLabel(coordinates(city_names),labels=city_names$NAME_EN,col="brown",offset=1000,cex=1.75)
map.scale(x=35.7, y= 34.625, ratio=FALSE, relwidth=0.25)
plot(nightlights0906,col=colorRampPalette(c("blue", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
title("Change from 2006 to 2009 Unshifted", line = 0.25)
plot(city_names,col="transparent",border="green",add=T)
plot(nightlights0906shift,col=colorRampPalette(c("blue", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
title("Change from 2006 to 2009 Shifted", line = 0.25)
plot(city_names,col="transparent",border="green",add=T)
detach(mtcars)


###FIGURE 4: 2008 and 2009 ####

origin(nightlights2009)<-0
origin(nightlights2008)<-0
nightlights0908<-nightlights2009-nightlights2008
nightlights2009shift<-raster::shift(nightlights2009,dx=0.0043894,dy=0.015704)
origin(nightlights2009shift)<-0
origin(nightlights0908)<-0
nightlights0908shift<-nightlights2009shift-nightlights2008

attach(mtcars)
par(mfrow=c(2,3),mai = c(.005, 0.05, 0.15, 0.05), mar=c(0,1,1,1))
plot(nightlights2008,col=colorRampPalette(c("black", "white"))(255),axes=FALSE,xlim = c(35.7,37.2), ylim = c(34.5, 35.7),legend=F)
plot(city_names,col="transparent",border="green",add=T)
title("2008 Composite", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(nightlights2009,col=colorRampPalette(c("black", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE,legend=F)
plot(city_names,col="transparent",border="green",add=T)
title("2009 Composite", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(nightlights2009shift,col=colorRampPalette(c("black", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
plot(city_names,col="transparent",border="green",add=T)
title("2009 Composite Corrected", line = 0.25)
segments(35.7,35.6,37.2,35.6,col="green",lwd=1.5)
segments(35.7,35.3,37.2,35.3,col="green",lwd=1.5)
segments(35.7,35.1,37.2,35.1,col="green",lwd=1.5)
segments(35.7,34.85,37.2,34.85,col="green",lwd=1.5)
segments(35.7,34.7,37.2,34.7,col="green",lwd=1.5)

plot(bua_l4,xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE,border="gray")
title("Built-up Areas", line = 0.25)
plot(syr_adm1,add=T)
plot(city_names,col="blue",add=T)
pointLabel(coordinates(city_names),labels=city_names$NAME_EN,col="brown",offset=1000,cex=1.75)
map.scale(x=35.7, y= 34.625, ratio=FALSE, relwidth=0.25)
plot(nightlights0908,col=colorRampPalette(c("blue", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
title("Change from 2008 to 2009 Unshifted", line = 0.25)
plot(city_names,col="transparent",border="green",add=T)
plot(nightlights0908shift,col=colorRampPalette(c("blue", "white"))(255),xlim = c(35.7,37.2), ylim = c(34.5, 35.7),axes=FALSE)
title("Change from 2008 to 2009 Shifted", line = 0.25)
plot(city_names,col="transparent",border="green",add=T)
detach(mtcars)


##Appendix 3: Intercalibrated nightlights from Elvidge (2009,2014)
nightlights2007 <- raster('~/F162007.v4/F162007.v4b_web.stable_lights.avg_vis.tif/F162007.v4b_web.stable_lights.avg_vis.tif')
nightlights2009 <- raster('~/F162009.v4/F162009.v4b_web.stable_lights.avg_vis.tif/F162009.v4b_web.stable_lights.avg_vis.tif')
nightlights2007<-crop(nightlights2007,syria_shape)
nightlights2009<-crop(nightlights2009,syria_shape)
nightlights2007ic<-0.6394+0.9114*nightlights2007+0.0014*(nightlights2007^2)
nightlights2009ic<-0.9492+1.0683*nightlights2009-0.0016*(nightlights2009^2)
origin(nightlights2009ic)<-0
origin(nightlights2007ic)<-0
origin(nightlights2007)<-0
nightlights0907ic<-nightlights2009ic-nightlights2007ic
nightlights2007change<-nightlights2007ic-nightlights2007
nightlightschangechange<-nightlights0907ic-nightlights0907
###FIGURE 5####

plot(nightlightschangechange,axes=FALSE,col=colorRampPalette(c("blue", "white"))(255))
plot(syria_shape,add=TRUE,lwd=3,border="red")
origin(nightlightschangechange)<-0
origin(nightlights0907)<-0

##Looking only at unsaturated cells in 2007
###FIGURE 8####

nightlights2007[nightlights2007>60]<-NA
nightlights0907nosat<-nightlights2009-nightlights2007

syr_adm3<-readOGR(dsn="~/kakm_remotesensing_replicationcode/", layer="syr_admin3_clip")

extracted.l3.nosat <- extract(nightlights0907nosat, syr_adm3, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
extracted.l3.orig <- extract(nightlights0907, syr_adm3, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
avg.nosat0907<-extracted.l3.nosat@data$layer
avg.nosat0907orig<-extracted.l3.orig@data$layer

syr_merge_0907light<-cbind(syr_adm3@data,avg.nosat0907)
syr_merge_0907light<-cbind(syr_adm3@data,avg.nosat0907orig)

syr_merge_0907light$satdiff<-syr_merge_0907light$avg.nosat0907orig-syr_merge_0907light$avg.nosat0907
syr_merge_0907light$l3_pcode<-syr_merge_0907light$PCODE
nosat0907<-data.frame(syr_merge_0907light$l3_pcode,syr_merge_0907light$avg.nosat0907)
nosat0907$l3_pcode<-nosat0907$syr_merge_0907light.l3_pcode
nosat0907$nosat0907<-nosat0907$syr_merge_0907light.avg.nosat0907

xx$nosatnoflares0907squared<-NULL
xx$ligmean_change_0907squared<-NULL
xx$nosatnoflares0907<-NULL
xx$syr_merge_0907nosatnoflares.avg.nosat0907.noflares<-NULL
xx$syr_merge_0907nosatnoflares.PCODE<-NULL
xx$noflares0907<-NULL
xx$syr_merge_0907noflares.avg.0907.noflares<-NULL
xx$syr_merge_0907nosatnoflares.PCODE<-NULL
xx$syr_merge_0907noflares.PCODE<-NULL
xx$nosat0907<-NULL
xx$syr_merge_0907light.l3_pcode<-NULL

xx <- merge(xx, nosat0907,by="l3_pcode",all= TRUE)
names(xx)
###TABLE 6 start####

nosat0907 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + nosat0907+ factor(gov_id), family=binomial(link="logit"), data=xx)
vcov_base <- cluster.vcov(nosat0907, cbind(xx$gov_id))
nosat0907<-round(coeftest(nosat0907, vcov_base),3)
nosat0907
###Remove areas surrounded by gas flare lights
gas_flares_area<-readOGR(dsn="~/kakm_remotesensing_replicationcode/", layer="Flares_Syria_1")
###FIGURE 6####
plot(nightlights0907nosat)
syr_adm3_noflares2<-syr_adm3-gas_flares_area
plot(syr_adm3_noflares2)

extracted.l3.noflares <- extract(nightlights0907, syr_adm3_noflares2, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
avg.0907.noflares<-extracted.l3.noflares@data$layer
syr_merge_0907noflares<-cbind(syr_adm3_noflares2@data,avg.0907.noflares)
noflares0907<-data.frame(syr_merge_0907noflares$PCODE,syr_merge_0907noflares$avg.0907.noflares)
noflares0907$l3_pcode<-noflares0907$syr_merge_0907noflares.PCODE
noflares0907$noflares0907<-noflares0907$syr_merge_0907noflares.avg.0907.noflares
xx <- merge(xx, noflares0907,by="l3_pcode",all= TRUE)
###TABLE 6####

noflares0907 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + noflares0907+ factor(gov_id), family=binomial(link="logit"), data=xx)
vcov_base <- cluster.vcov(noflares0907, cbind(xx$gov_id))
noflares0907<-round(coeftest(noflares0907, vcov_base),3)
noflares0907


###Remove areas surrounded by gas flare lights from nonsaturated only
extracted.l3.nosat.noflares <- extract(nightlights0907nosat, syr_adm3_noflares2, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
avg.nosat0907.noflares<-extracted.l3.nosat.noflares@data$layer
syr_merge_0907nosatnoflares<-cbind(syr_adm3_noflares2@data,avg.nosat0907.noflares)
nosatnoflares0907<-data.frame(syr_merge_0907nosatnoflares$PCODE,syr_merge_0907nosatnoflares$avg.nosat0907.noflares)
nosatnoflares0907$l3_pcode<-nosatnoflares0907$syr_merge_0907nosatnoflares.PCODE
nosatnoflares0907$nosatnoflares0907<-nosatnoflares0907$syr_merge_0907nosatnoflares.avg.nosat0907.noflares
xx <- merge(xx, nosatnoflares0907,by="l3_pcode",all= TRUE)



nosatnoflares0907 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + nosatnoflares0907+factor(gov_id), family=binomial(link="logit"), data=xx)
vcov_base <- cluster.vcov(nosatnoflares0907, cbind(xx$gov_id))
nosatnoflares0907<-round(coeftest(nosatnoflares0907, vcov_base),3)
nosatnoflares0907

stargazer(base,nosat0907, noflares0907,nosatnoflares0907,
          title            = "Replication of De Juan and Bank (2015) Adjusting for Saturation and Gas Flares",
          covariate.labels = c("Gov. Employees", "Sunni", "Alawi",
                               "School Enrollment", "Border Dist. (log)", "Urbanization", "Electrification", "Pct. Unemployed", "Road Density", "Population (log)",
                               "Lights Change (Original)", "Lights Change (No Saturated Pixels)", "Lights Change (No Gas Flares)", "Lights Change (Unsaturated) No Flares)"),
          dep.var.caption  = "25 or more deaths in sub-district (binary)")



###TABLE 7: Using the desaturated nightlights from 2006 and 2010
nightlights2010rc <- raster('~/F16_20100111-20101209_rad_v4.avg_vis.tif')
nightlights2006rc <- raster('~/F16_20051128-20061224_rad_v4.avg_vis.tif')
nightlights2006orig <- raster('~/F162006.v4/F162006.v4b_web.stable_lights.avg_vis.tif/F162006.v4b_web.stable_lights.avg_vis.tif')
cellStats(nightlights2010rc,stat='mean')
cellStats(nightlights2006rc,stat='mean')
nightlights2006rc<-crop(nightlights2006rc,syria_shape)
nightlights2006orig<-crop(nightlights2006orig,syria_shape)

stack2006<-stack(nightlights2006rc,nightlights2006orig)
cor(values(stack2006)[,1],
    values(stack2006)[,2],
    use = "na.or.complete")

###The non-saturated areas of the lights are highly correlated -- .985
nightlights2006nosat<-nightlights2006orig
nightlights2006nosat[nightlights2006nosat==63]<-NA
nightlights2006nosat2<-nightlights2006
nightlights2006nosat2[nightlights2006nosat2>62]<-NA

stack2006nosat<-stack(nightlights2006nosat,nightlights2006nosat2)
cor(values(stack2006nosat)[,1],
    values(stack2006nosat)[,2],
    use = "na.or.complete")

nightlights2010rc<-crop(nightlights2010rc,syria_shape)
extent(nightlights2006rc)
extent(nightlights2010rc)
plot(nightlights2006rc)
plot(nightlights2010rc)
nightlights1006nosat<-nightlights2010rc-nightlights2006rc
plot(nightlights1006nosat)
writeRaster(nightlights1006nosat,'nightlights1006nosat',format="GTiff",overwrite=TRUE)


extracted.l3.nosat1006 <- extract(nightlights1006nosat, syr_adm3, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
extracted.l3.nosat1006.flares <- extract(nightlights1006nosat, syr_adm3_noflares2, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
avg.nosat1006<-extracted.l3.nosat1006@data$layer
avg.nosat1006.noflares2<-extracted.l3.nosat1006.flares@data$layer
syr_merge_1006<-cbind(syr_adm3@data,avg.nosat1006)
syr_merge_1006noflares2<-cbind(syr_adm3_noflares2@data,avg.nosat1006.noflares2)
nosat1006<-data.frame(syr_merge_1006$PCODE,syr_merge_1006$avg.nosat1006)
nosatnoflares1006<-data.frame(syr_merge_1006noflares2$PCODE,syr_merge_1006noflares2$avg.nosat1006.noflares2)
nosat1006$l3_pcode<-nosat1006$syr_merge_1006.PCODE
nosatnoflares1006$l3_pcode<-nosatnoflares1006$syr_merge_1006noflares2.PCODE
nosat1006$nosat1006<-nosat1006$syr_merge_1006.avg.nosat1006
nosatnoflares1006$nosatnoflares1006<-nosatnoflares1006$syr_merge_1006noflares2.avg.nosat1006.noflares2

xx$nosatnoflares1006<-NULL
xx$nosatnoflares1006squared<-NULL
xx$syr_merge_1006noflares2.avg.nosat1006.noflares2<-NULL
xx$syr_merge_1006noflares2.PCODE<-NULL
xx$nosat1006<-NULL
xx$syr_merge_1006.avg.nosat1006<-NULL
xx$syr_merge_1006.PCODE<-NULL
xx$nosat1006squared<-NULL

xx <- merge(xx, nosat1006,by="l3_pcode",all= TRUE)
xx <- merge(xx, nosatnoflares1006,by="l3_pcode",all= TRUE)

nosat1006 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004+ nosat1006 +factor(gov_id), family=binomial(link="logit"), data=xx)
vcov_base <- cluster.vcov(nosat1006, cbind(xx$gov_id))
nosat1006<-round(coeftest(nosat1006, vcov_base),3)
nosat1006

nosatnoflares1006 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + nosatnoflares1006+factor(gov_id), family=binomial(link="logit"), data=xx)
vcov_base <- cluster.vcov(nosatnoflares1006, cbind(xx$gov_id))
nosatnoflares1006<-round(coeftest(nosatnoflares1006, vcov_base),3)
nosatnoflares1006

###Figure for Gas Flare Area comparisson####
###FIGURE 7####

deirezzor<-subset(syr_adm3,ADMIN1_EN=="Deir-ez-Zor")
hasakeh<-subset(syr_adm3,ADMIN1_EN=="Al-Hasakeh")
hama<-subset(syr_adm3,ADMIN1_EN=="Hama")
homs<-subset(syr_adm3,ADMIN1_EN=="Homs")
raqqa<-subset(syr_adm3,ADMIN1_EN=="Ar-Raqqa")
djb_flares_govs<-aggregate(rbind(deirezzor, hasakeh,hama,homs,raqqa))
plot(syria_shape,col="transparent")
plot(djb_flares_govs,col="blue",add=T)
plot(syr_adm3,col="transparent",add=T)
plot(gas_flares_area,col="red", add=T)

####Tables####



#Original model, excluding saturated pixels in 2007, excluding gas flares, excluding both, using nonsaturated data from 1006, removing flares from 1006
stargazer(base,nosat0907, noflares0907,nosatnoflares0907,nosat1006,nosatnoflares1006,
          title            = "Replication of De Juan and Bank (2015) Adjusting for Saturation and Gas Flarest",
          covariate.labels = c("Gov. Employees", "Sunni", "Alawi",
                               "School Enrollment", "Border Dist. (log)", "Urbanization", "Electrification", "Pct. Unemployed", "Road Density", "Population (log)",
                               "Lights Change (Original)", "Lights Change (No Saturated Pixels)", "Lights Change (No Gas Flares)", "Lights Change (No Sat. No Flares)", "Lights Change (2010 from 2006 saturation adjusted)", "Lights Change (2010 to 2006 sat. adj. no flares)"),
          dep.var.caption  = "25 or more deaths in sub-district (binary)")


write.csv(xx,"xx_updated_full.csv")

###Log of 1006 data

lnightlights2006<-log(nightlights2006)
plot(lnightlights2006)
lnightlights2006[!is.finite(lnightlights2006)] <- 0
lnightlights2006[!is.finite(lnightlights2006)] <- 0
lnightlights2010<-log(nightlights2010)
lnightlights2010[!is.finite(lnightlights2010)] <- 0
lnightlights2006[!is.finite(lnightlights2006)] <- 0
lnightlights1006<-lnightlights2010-lnightlights2006
lnightlights1006[!is.finite(lnightlights1006)] <- 0
lnightlights1006[is.na(lnightlights1006)] <- 0


plot(lnightlights1006)

extracted.l3.lnosat1006 <- extract(lnightlights1006, syr_adm3, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
extracted.l3.lnosat1006.flares <- extract(lnightlights1006, syr_adm3_noflares2, fun=mean, small=TRUE, sp=TRUE, na.rm=TRUE)
avg.lnosat1006<-extracted.l3.lnosat1006@data$layer
avg.lnosat1006.noflares2<-extracted.l3.lnosat1006.flares@data$layer
lsyr_merge_1006<-cbind(syr_adm3@data,avg.lnosat1006)
lsyr_merge_1006noflares2<-cbind(syr_adm3_noflares2@data,avg.lnosat1006.noflares2)
lnosat1006<-data.frame(lsyr_merge_1006$PCODE,lsyr_merge_1006$avg.lnosat1006)
lnosatnoflares1006<-data.frame(lsyr_merge_1006noflares2$PCODE,lsyr_merge_1006noflares2$avg.lnosat1006.noflares2)
lnosat1006$l3_pcode<-lnosat1006$lsyr_merge_1006.PCODE
lnosatnoflares1006$l3_pcode<-lnosatnoflares1006$lsyr_merge_1006noflares2.PCODE
lnosat1006$lnosat1006<-lnosat1006$lsyr_merge_1006.avg.lnosat1006
lnosatnoflares1006$lnosatnoflares1006<-lnosatnoflares1006$lsyr_merge_1006noflares2.avg.lnosat1006.noflares2

xx$lsyr_merge_1006.PCODE<-NULL
xx$lsyr_merge_1006.avg.lnosat1006<-NULL
xx$lnosat1006<-NULL
xx$lsyr_merge_1006noflares2.PCODE<-NULL
xx$lsyr_merge_1006noflares2.avg.lnosat1006.noflares2<-NULL
xx$lnosatnoflares1006<-NULL

xx <- merge(xx, lnosat1006,by="l3_pcode",all= TRUE)
xx <- merge(xx, lnosatnoflares1006,by="l3_pcode",all= TRUE)

lnosat1006 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004+ lnosat1006 +factor(gov_id), family=binomial(link="logit"), data=xx)
vcov_base <- cluster.vcov(lnosat1006, cbind(xx$gov_id))
lnosat1006<-round(coeftest(lnosat1006, vcov_base),3)
lnosat1006
xx$lnosatnoflares1006
lnosatnoflares1006 <- glm(dum_fat_total_25 ~ sc_emplgov + sunni+ alawites+ sc_enroll611 + log_border_dist + share_urban_2004 + sc_electricity + sc_malunempl + road_density + log_pop_2004 + lnosatnoflares1006+factor(gov_id), family=binomial(link="logit"), data=xx)
vcov_base <- cluster.vcov(lnosatnoflares1006, cbind(xx$gov_id))
lnosatnoflares1006<-round(coeftest(lnosatnoflares1006, vcov_base),3)
lnosatnoflares1006


stargazer(nosat1006,nosatnoflares1006,lnosat1006,lnosatnoflares1006,
          title            = "Replication of De Juan and Bank (2015) with Saturation Adjusted Nightlight Data",
          covariate.labels = c("Gov. Employees", "Sunni", "Alawi",
                               "School Enrollment", "Border Dist. (log)", "Urbanization", "Electrification", "Pct. Unemployed", "Road Density", "Population (log)",
                               "Lights Change (2010 from 2006 saturation adjusted)", "Lights Change (2010 to 2006 sat. adj. no flares)","Log Lights Change (2010 from 2006 saturation adjusted)", "Log Lights Change (2010 to 2006 sat. adj. no flares)"),
          dep.var.caption  = "25 or more deaths in sub-district (binary)")
